@@ -1,5 +1,5 @@
 document.getElementById("Contents").innerHTML='\
-    <ul><li><input type="checkbox" id="07"><label for="07">Makronaredbe i programiranje</label><ul>\
+    <ul><li><input type="checkbox" id="07"><label for="07">Macros and Scripting</label><ul>\
     <li><input type="checkbox" id="0701"><label for="0701">General Information and User Interface Usage</label><ul>\
     <li><a target="_top" href="hr/text/sbasic/shared/main0601.html">LibreOffice Basic pomoć</a></li>\
     <li><a target="_top" href="hr/text/sbasic/shared/01000000.html">Programming with LibreOffice Basic</a></li>\
@@ -124,6 +124,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/sbasic/shared/03090202.html">For...Next Statement</a></li>\
     <li><a target="_top" href="hr/text/sbasic/shared/03120301.html">Format Function</a></li>\
     <li><a target="_top" href="hr/text/sbasic/shared/03150000.html">FormatDateTime Function [VBA]</a></li>\
+    <li><a target="_top" href="hr/text/sbasic/shared/03170010.html">FormatNumber Function [VBA]</a></li>\
     <li><a target="_top" href="hr/text/sbasic/shared/03020102.html">FreeFile Function</a></li>\
     <li><a target="_top" href="hr/text/sbasic/shared/03090405.html">FreeLibrary Function</a></li>\
     <li><a target="_top" href="hr/text/sbasic/shared/03090406.html">Function Statement</a></li>\
@@ -297,7 +298,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/sbasic/guide/access2base.html">Access2Base</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="08"><label for="08">Proračunske tablice</label><ul>\
+    <ul><li><input type="checkbox" id="08"><label for="08">Spreadsheets (Calc)</label><ul>\
     <li><input type="checkbox" id="0801"><label for="0801">General Information and User Interface Usage</label><ul>\
     <li><a target="_top" href="hr/text/scalc/main0000.html">Welcome to the LibreOffice Calc Help</a></li>\
     <li><a target="_top" href="hr/text/scalc/main0503.html">LibreOffice Calc Features</a></li>\
@@ -477,7 +478,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/schart/04/01020000.html">Precac do grafikona</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="01"><label for="01">Instalacija</label><ul>\
+    <ul><li><input type="checkbox" id="01"><label for="01">LibreOffice Installation</label><ul>\
     <li><a target="_top" href="hr/text/shared/guide/ms_doctypes.html">Changing the Association of Microsoft Office Document Types</a></li>\
     <li><a target="_top" href="hr/text/shared/01/profile_safe_mode.html">Safe Mode</a></li>\
 	</ul></li></ul>\
@@ -503,7 +504,6 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/shared/optionen/01010200.html">Općenito</a></li>\
     <li><a target="_top" href="hr/text/shared/optionen/01010300.html">Putanje</a></li>\
     <li><a target="_top" href="hr/text/shared/optionen/01010400.html">Pomagala za pisanje</a></li>\
-    <li><a target="_top" href="hr/text/shared/optionen/01010500.html">Color</a></li>\
     <li><a target="_top" href="hr/text/shared/optionen/01010600.html">Općenito</a></li>\
     <li><a target="_top" href="hr/text/shared/optionen/01010700.html">Pisma</a></li>\
     <li><a target="_top" href="hr/text/shared/optionen/01010800.html">Pogled</a></li>\
@@ -661,7 +661,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/shared/guide/numbering_stop.html">Turning off Bullets and Numbering for Individual Paragraphs</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="09"><label for="09">Database Functionality</label><ul>\
+    <ul><li><input type="checkbox" id="09"><label for="09">Database Functionality (Base)</label><ul>\
     <li><input type="checkbox" id="0901"><label for="0901">Opće informacije</label><ul>\
     <li><a target="_top" href="hr/text/shared/explorer/database/main.html">LibreOffice Database</a></li>\
     <li><a target="_top" href="hr/text/shared/guide/database_main.html">Database Overview</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">Presentations and Drawings</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">Presentations and Drawings (Impress/Draw)</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">Opće informacije i korištenje korisničkog sučelja</label><ul>\
     <li><a target="_top" href="hr/text/simpress/main0000.html">Welcome to the LibreOffice Impress Help</a></li>\
     <li><a target="_top" href="hr/text/sdraw/main0000.html">Welcome to the LibreOffice Draw Help</a></li>\
@@ -820,7 +820,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/simpress/guide/rehearse_timings.html">Ponovi</a></li>\
          </ul></li>\
      </ul></li></ul>\
-    <ul><li><input type="checkbox" id="03"><label for="03">Formule</label><ul>\
+    <ul><li><input type="checkbox" id="03"><label for="03">Formulas (Math)</label><ul>\
     <li><input type="checkbox" id="0301"><label for="0301">Opće informacije i korištenje korisničkog sučelja</label><ul>\
     <li><a target="_top" href="hr/text/smath/main0000.html">Welcome to the LibreOffice Math Help</a></li>\
     <li><a target="_top" href="hr/text/smath/main0503.html">LibreOffice Math Features</a></li>\
@@ -840,7 +840,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/smath/guide/parentheses.html">Inserting Brackets</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="02"><label for="02">Tekstni dokumenti</label><ul>\
+    <ul><li><input type="checkbox" id="02"><label for="02">Text Documents (Writer)</label><ul>\
     <li><input type="checkbox" id="0201"><label for="0201">Opće informacije i korištenje korisničkog sučelja</label><ul>\
     <li><a target="_top" href="hr/text/swriter/main0000.html">Dobrodošli u Pomoć LibreOffice Writera</a></li>\
     <li><a target="_top" href="hr/text/swriter/main0503.html">Svojstva LibreOffice Writer-a</a></li>\
@@ -887,7 +887,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/swriter/librelogo/LibreLogo.html">LibreLogo Toolbar</a></li>\
 			</ul></li>\
 		</ul></li>\
-    <li><input type="checkbox" id="0203"><label for="0203">Stvaranje tekstnog dokumneta</label><ul>\
+    <li><input type="checkbox" id="0203"><label for="0203">Stvaranje tekstualnog dokumenta</label><ul>\
     <li><a target="_top" href="hr/text/swriter/guide/text_nav_keyb.html">Navigating and Selecting With the Keyboard</a></li>\
     <li><a target="_top" href="hr/text/swriter/guide/text_direct_cursor.html">Using the Direct Cursor</a></li>\
 		</ul></li>\
@@ -1049,7 +1049,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="hr/text/shared/01/02100001.html">Popis regularnih izraza</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="06"><label for="06">HTML dokumenti</label><ul>\
+    <ul><li><input type="checkbox" id="06"><label for="06">HTML Documents (Writer Web)</label><ul>\
     <li><a target="_top" href="hr/text/shared/07/09000000.html">Web-stranice</a></li>\
     <li><a target="_top" href="hr/text/shared/02/01170700.html">HTML Filters and Forms</a></li>\
     <li><a target="_top" href="hr/text/swriter/guide/send2html.html">Spremanje teksta u HTML formatu</a></li>\
